@@ -140,7 +140,8 @@
 #' \item If \code{DM} is specified for a particular data stream, then the initial values are specified on 
 #' the working (i.e., beta) scale of the parameters. The working scale of each parameter is determined by the link function used.
 #' If a parameter P is bound by (0,Inf) then the working scale is the log(P) scale.  If the parameter bounds are (-pi,pi) then the working 
-#' scale is tan(P/2) unless circular-circular regression is used. Otherwise if the parameter bounds are finite then logit(P) is the working scale.  
+#' scale is tan(P/2) unless circular-circular regression is used. Otherwise if the parameter bounds are finite then logit(P) is the working scale. However, when both 
+#' zero- and one-inflation are included, then a multinomial logit link is used because the sum of the zeromass and onemass probability parameters cannot exceed 1.
 #' The function \code{\link{getParDM}} is intended to help with obtaining initial values on the working scale when specifying a design matrix and other 
 #' parameter constraints (see example below). When circular-circular regression is specified using \code{circularAngleMean}, the working scale 
 #' for the mean turning angle is not as easily interpretable, but the 
@@ -310,6 +311,7 @@
 #' m.cosinor    
 #' 
 #' ### 9. Piecewise constant B-spline on step length mean and angle concentration
+#' library(splines2)
 #' nObs <- 1000 # length of simulated track
 #' cov <- data.frame(time=1:nObs) # time covariate for splines
 #' dist <- list(step="gamma",angle="vm")
@@ -523,7 +525,7 @@ fitHMM <- function(data,nbStates,dist,
     if(is.null(DM[[i]])){
       if(zeroInflation[[i]]){
         # check that zero-mass is in the open interval (0,1)
-        zm0 <- Par0[[i]][(length(Par0[[i]])-nbStates+1):length(Par0[[i]])]
+        zm0 <- Par0[[i]][(length(Par0[[i]])-nbStates*oneInflation[[i]]-nbStates+1):(length(Par0[[i]])-nbStates*oneInflation[[i]])]
         zm0[which(zm0==0)] <- 1e-8
         zm0[which(zm0==1)] <- 1-1e-8
         Par0[[i]][(length(Par0[[i]])-nbStates*oneInflation[[i]]-nbStates+1):(length(Par0[[i]])-nbStates*oneInflation[[i]])] <- zm0
@@ -540,7 +542,7 @@ fitHMM <- function(data,nbStates,dist,
 
   mHind <- (is.null(DM) & is.null(userBounds) & ("step" %in% distnames) & is.null(fixPar) & !length(attr(terms.formula(newformula),"term.labels")) & !length(attr(terms.formula(formulaDelta),"term.labels")) & stationary) # indicator for moveHMMwrap below
   
-  inputs <- checkInputs(nbStates,dist,Par0,estAngleMean,circularAngleMean,zeroInflation,oneInflation,DM,userBounds,cons,workcons,stateNames)
+  inputs <- checkInputs(nbStates,dist,Par0,estAngleMean,circularAngleMean,zeroInflation,oneInflation,DM,userBounds,cons,workcons,stateNames,checkInflation = TRUE)
   p <- inputs$p
   
   DMinputs<-getDM(data,inputs$DM,dist,nbStates,p$parNames,p$bounds,Par0,inputs$cons,inputs$workcons,zeroInflation,oneInflation,inputs$circularAngleMean)
