@@ -11,7 +11,7 @@ getXB<-function(DM,nbObs,wpar,cons,workcons,DMind,circularAngleMean,nbStates,nc,
   } else {
     if(length(meanind)) XB<-XBloop_rcpp(DM,Xvec,nbObs,nrw,ncl,circularAngleMean,meanind-1,nc)
     else XB <- matrix(0,nrw,nbObs)
-    XB[nbStates+1:nbStates,]<-XBloop_rcpp(DM[nbStates+1:nbStates,],Xvec,nbObs,nbStates,ncl,FALSE,1:nbStates-1,nc[nbStates+1:nbStates,])
+    XB[nbStates+1:nbStates,]<-XBloop_rcpp(DM[nbStates+1:nbStates,,drop=FALSE],Xvec,nbObs,nbStates,ncl,FALSE,1:nbStates-1,nc[nbStates+1:nbStates,,drop=FALSE])
   }
   XB
 }
\ No newline at end of file
